/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.dao.impl;



import dk.sundhedsdatastyrelsen.organdonor.domain.OrganDonorVO;
import dk.sundhedsdatastyrelsen.organdonor.domain.PermissionType;
import org.springframework.jdbc.core.RowMapper;

import java.sql.ResultSet;
import java.sql.SQLException;

public class OrganDonorRowMapper implements RowMapper<OrganDonorVO> {
    @Override
    public OrganDonorVO mapRow(ResultSet resultSet, int i) throws SQLException {
        final OrganDonorVO organDonorVO = new OrganDonorVO();
        organDonorVO.setOrganDonorPID(resultSet.getInt("OrganDonorPID"));
        organDonorVO.setPersonIdentifier(resultSet.getString("PersonIdentifier"));
        organDonorVO.setVersion(resultSet.getInt("Version"));
        organDonorVO.setModifiedDateTime(resultSet.getTimestamp("ModifiedDateTime").toInstant());
        organDonorVO.setValidFrom(resultSet.getTimestamp("ValidFrom").toInstant());
        organDonorVO.setValidTo(resultSet.getTimestamp("ValidTo").toInstant());
        organDonorVO.setPermissionType(PermissionType.fromDatabaseValue(resultSet.getString("PermissionType")));
        organDonorVO.setHeart(mapBooleanJavaNull("Heart", resultSet));
        organDonorVO.setKidneys(mapBooleanJavaNull("Kidneys", resultSet));
        organDonorVO.setLungs(mapBooleanJavaNull("Lungs", resultSet));
        organDonorVO.setCorneas(mapBooleanJavaNull("Corneas", resultSet));
        organDonorVO.setLiver(mapBooleanJavaNull("Liver", resultSet));
        organDonorVO.setSmallIntestine(mapBooleanJavaNull("SmallIntestine", resultSet));
        organDonorVO.setPancreas(mapBooleanJavaNull("Pancreas", resultSet));
        organDonorVO.setSkin(mapBooleanJavaNull("Skin", resultSet));
        organDonorVO.setRelativeAcceptanceRequired(mapBooleanJavaNull("RelativeAcceptanceRequired", resultSet));

        return organDonorVO;
    }

    private Boolean mapBooleanJavaNull(String columnLabel, ResultSet resultSet) throws SQLException {
        final Boolean b = resultSet.getBoolean(columnLabel);
        return resultSet.wasNull() ? null : b;
    }
}
