/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.slettejob;

import com.fasterxml.jackson.databind.ObjectMapper;
import dk.sundhedsdatastyrelsen.organdonor.conf.AbstractHttpServlet;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;

import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.time.format.DateTimeFormatter;
import java.util.HashMap;
import java.util.Map;

@WebServlet(name = "HealthServlet", urlPatterns = {"/odr-slettejob/status"})
public class HealthServlet extends AbstractHttpServlet {

    private static final Logger log = Logger.getLogger(HealthServlet.class);

    @Autowired
    private DeleteOrganDonorRegistrationJob sletteJob;

    @Override
    public void doGet(HttpServletRequest request, HttpServletResponse response) {
        try {
            Map<String, String> map = getSlettejobtatus();
            response.setContentType("application/json");
            String json = new ObjectMapper().writeValueAsString(map);
            response.getWriter().write(json);
            response.setStatus(HTTP_OK);
        } catch (Exception e) {
            log.error("Error while calling HealthServlet", e);
            response.setStatus(HTTP_INTERNAL_SERVER_ERROR);
        }
    }

    private Map<String, String> getSlettejobtatus() {
        DateTimeFormatter FOMATTER = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

        HashMap<String, String> map = new HashMap<>();
        map.put("timeOfLastExecution", sletteJob.getTimeOfLastExecution() == null ? "" : FOMATTER.format(sletteJob.getTimeOfLastExecution()));
        map.put("lastExecutionSucceeded", sletteJob.getLastExecutionSucceeded() == null ? "" : sletteJob.getLastExecutionSucceeded().toString());
        if (sletteJob.getLastException() != null) {
            map.put("lastException", sletteJob.getLastException().getMessage());
        }
        return map;
    }
}
