/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.slettejob;

import dk.sundhedsdatastyrelsen.organdonor.OID;
import dk.sundhedsdatastyrelsen.organdonor.domain.OrganDonorVO;
import dk.sundhedsdatastyrelsen.organdonor.domain.PermissionType;
import dk.sundhedsdatastyrelsen.organdonor.domain.RequestContextVO;
import dk.sundhedsdatastyrelsen.organdonor.domain.ServiceActorVO;
import dk.sundhedsdatastyrelsen.organdonor.domain.UserType;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Component;

import java.sql.Types;
import java.time.Instant;
import java.time.temporal.ChronoUnit;

@Component
public class ServiceTestHelper {
    public static final String ORG_NAME = "OrgName";
    public static final String ORG_ID = OID.SOR;

    public static final PermissionType PERMISSIONTYPE = PermissionType.FULL;
    public static final Boolean HEART = true;
    public static final Boolean LUNGS = true;
    public static final Boolean LIVER = false;
    public static final Boolean PANCREAS = false;
    public static final Boolean KIDNEYS = true;
    public static final int VERSION = 10;

    protected NamedParameterJdbcTemplate namedParamJdbcTemplate;


    public ServiceActorVO getServiceActorExample(String personIdentifier, UserType userType) {
        ServiceActorVO serviceActorVO = new ServiceActorVO(userType);
        serviceActorVO.setOrganizationId(ORG_ID);
        serviceActorVO.setOrganizationName(ORG_NAME);
        serviceActorVO.setPersonIdentifier(personIdentifier);
        return serviceActorVO;
    }

    public RequestContextVO getRequestContextExample(String personIdentifier, String messageId) {
        return getRequestContextExample(personIdentifier, UserType.Citizen, messageId);
    }

    public RequestContextVO getRequestContextExample(String personIdentifier, UserType userType, String messageId) {
        ServiceActorVO actor = getServiceActorExample(personIdentifier, userType);
        RequestContextVO requestContextVO = new RequestContextVO(actor, null);
        requestContextVO.setPersonIdentifier(personIdentifier);
        requestContextVO.setMessageId(messageId);
        return requestContextVO;
    }

    protected OrganDonorVO getOrganDonorRegistrationExample(String personIdentifier) {
        OrganDonorVO organDonorVO = new OrganDonorVO();
        organDonorVO.setPersonIdentifier(personIdentifier);
        organDonorVO.setPermissionType(PERMISSIONTYPE);
        organDonorVO.setHeart(HEART);
        organDonorVO.setLungs(LUNGS);
        organDonorVO.setLiver(LIVER);
        organDonorVO.setPancreas(PANCREAS);
        organDonorVO.setKidneys(KIDNEYS);
        organDonorVO.setVersion(VERSION);
        return organDonorVO;
    }

    protected void createPerson(String cpr, String status, Instant statusDato, Instant validFrom, Instant validTo) {
        createPerson(cpr, "Hans", "Nielsen", status, statusDato, validFrom, validTo);
    }

    protected void createPerson(String cpr, String fornavn, String efternavn, String status, Instant statusDato, Instant validFrom, Instant validTo) {
        Instant statusDatoTruncated = statusDato.truncatedTo(ChronoUnit.SECONDS);
        Instant validFromTruncated = validFrom.truncatedTo(ChronoUnit.SECONDS);
        Instant validToTruncated = validTo.truncatedTo(ChronoUnit.SECONDS);

        String sql = "INSERT INTO `v2_Person` (`CPR`,`Fornavn`,`Efternavn`,`Status`,`StatusDato`,`CreatedDate`,`ModifiedDate`,`ValidFrom`,`ValidTo`) VALUES \n" +
                "(:cpr,:fornavn,:efternavn,:status,:statusDato,:validFrom,:validFrom,:validFrom,:validTo)";

        final MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("cpr", cpr, Types.CHAR);
        parameters.addValue("fornavn", fornavn, Types.VARCHAR);
        parameters.addValue("efternavn", efternavn, Types.VARCHAR);
        parameters.addValue("status", status, Types.CHAR);
        parameters.addValue("statusDato", java.sql.Timestamp.from(statusDatoTruncated), Types.TIMESTAMP);
        parameters.addValue("validFrom", java.sql.Timestamp.from(validFromTruncated), Types.TIMESTAMP);
        parameters.addValue("validTo", java.sql.Timestamp.from(validToTruncated), Types.TIMESTAMP);

        namedParamJdbcTemplate.update(sql, parameters);
    }

    protected void closeCprRecord(String cpr, Instant atDate) {
        Instant atDateTruncated = atDate.truncatedTo(ChronoUnit.SECONDS);

        String sql = "UPDATE v2_Person SET validTo = :validTo WHERE CPR = :cpr and ValidTo > now()";
        final MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("validTo", java.sql.Timestamp.from(atDateTruncated), Types.TIMESTAMP);
        parameters.addValue("cpr", cpr, Types.CHAR);
        namedParamJdbcTemplate.update(sql, parameters);
    }
}
