/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.slettejob;

import java.io.IOException;

import dk.sundhedsdatastyrelsen.organdonor.conf.TestConfig;
import dk.sundhedsdatastyrelsen.organdonor.conf.TestDAOConfig;
import dk.sundhedsdatastyrelsen.organdonor.conf.TestDBScriptPreprocessor;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.mock.web.MockHttpServletRequest;
import org.springframework.mock.web.MockHttpServletResponse;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringRunner;

@RunWith(SpringRunner.class)
@ActiveProfiles("development")
@ContextConfiguration(classes = {TestConfig.class, TestDAOConfig.class, TestDBScriptPreprocessor.class})
public class SlettejobServletTest extends ServiceTestHelper {

    @Autowired
    private SlettejobServlet slettejobServlet;
    @Autowired
    private HealthServlet healthServlet;

    @Test
    public void testSlettejobStart() throws IOException {
        // given
        MockHttpServletRequest request = new MockHttpServletRequest("GET", "/odr-operations/odr-slettejob/start");
        MockHttpServletResponse response = new MockHttpServletResponse();

        // when
        slettejobServlet.doGet(request, response);

        // then
        Assert.assertEquals(200, response.getStatus());
    }

    @Test
    public void testSlettejobStatus() throws IOException {
        MockHttpServletRequest request = new MockHttpServletRequest("GET", "/odr-operations/odr-slettejob/status");
        MockHttpServletResponse response = new MockHttpServletResponse();

        // When
        healthServlet.doGet(request, response);

        Assert.assertEquals(200, response.getStatus());
        Assert.assertTrue(response.getContentAsString().contains("\"lastExecutionSucceeded\""));
    }
}
