/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.wildfly;

import org.junit.Assert;
import org.junit.Test;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.nio.charset.StandardCharsets;
import java.util.stream.Collectors;

public class SletteJobIT {

    private int responseCode;

    private String slettejobStartEndpoint = System.getProperty("itOdrOperationsAddress", "http://localhost:8081/odr-operations") + "/odr-slettejob/start";
    private String slettejobStatusEndpoint = System.getProperty("itOdrOperationsAddress", "http://localhost:8081/odr-operations") + "/odr-slettejob/status";

    @Test
    public void testStartEndpoint() throws IOException {
        System.out.println("ENDPOINT=" + slettejobStartEndpoint);
        String response = get(slettejobStartEndpoint);
        Assert.assertEquals(200, responseCode);
    }

    @Test
    public void testStatusEndpoint() throws IOException {
        String response = get(slettejobStatusEndpoint);
        Assert.assertEquals(200, responseCode);
        Assert.assertTrue(response.contains("timeOfLastExecution"));
        Assert.assertTrue(response.contains("lastExecutionSucceeded"));
    }

    private String get(String endpoint) throws IOException {
        URL wsdlUrl = new URL(endpoint);
        HttpURLConnection connection = (HttpURLConnection) wsdlUrl.openConnection();
        connection.setRequestMethod("GET");

        responseCode = connection.getResponseCode();
        try {
            return new BufferedReader(new InputStreamReader(connection.getInputStream(), StandardCharsets.UTF_8))
                    .lines()
                    .collect(Collectors.joining("\n"));
        } catch (IOException e) {
            return "";
        }
    }
}
