/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.service;

import dk.sundhedsdatastyrelsen.organdonor.conf.AbstractHttpServlet;
import dk.sundhedsdatastyrelsen.organdonor.util.Properties;
import org.apache.http.HttpHeaders;
import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;

import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;
import java.time.Instant;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;

@WebServlet(name="DKSServlet", urlPatterns={"/dksconfig"})
public class DKSServlet extends AbstractHttpServlet {
    private static final Logger log = LogManager.getLogger(DKSServlet.class);

    private static final String RESOURCE_NAME = "/dksconfig/odr.xml";
    private static final String DATETIME_FORMAT = "yyyy-MM-dd'T'HH:mm:ss'Z'";

    @Autowired
    private Properties properties;

    @Override
    public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException {
        log.debug("dksconfig request");
        response.setContentType("application/xml");
        response.setStatus(200);
        response.addHeader(HttpHeaders.CACHE_CONTROL, "no-cache");
        String resp = dksConfig();
        response.getWriter().print(resp);
    }

    private String dksConfig() throws IOException {
        URL url = getClass().getResource(RESOURCE_NAME);
        ZonedDateTime zdt = ZonedDateTime.ofInstant(Instant.ofEpochMilli(url.openConnection().getLastModified()), ZoneId.systemDefault());
        DateTimeFormatter dateTimeFormatter = DateTimeFormatter.ofPattern(DATETIME_FORMAT);
        String filetimestamp = dateTimeFormatter.format(zdt);

        InputStream in = getClass().getResourceAsStream(RESOURCE_NAME);
        BufferedReader reader = new BufferedReader(new InputStreamReader(in));
        StringBuilder out = new StringBuilder();
        String line;
        while ((line = reader.readLine()) != null) {
            out.append(line);
        }

        return getStringWithResolvedVariables(out, filetimestamp);
    }

    private String getStringWithResolvedVariables(StringBuilder template, String filetimestamp) {
        int timestampIndex = template.indexOf("TIMESTAMP");
        template = template.replace(timestampIndex, timestampIndex + 9, filetimestamp);

        return template.toString().replace("ENDPOINT_PLACEHOLDER", properties.getDccEndpoint());
    }
}


