/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.service.business;

import dk.sundhedsdatastyrelsen.organdonor.domain.RequestContextVO;
import dk.sundhedsdatastyrelsen.organdonor.domain.UserType;
import dk.sundhedsdatastyrelsen.organdonor.service.util.FaultCode;
import dk.sundhedsdatastyrelsen.organdonor.service.util.FaultUtil;
import dk.sundhedsdatastyrelsen.organdonor.service.util.ODRException;
import org.springframework.stereotype.Component;

@Component
public class AccessControlImpl implements AccessControl {

    @Override
    public void checkGetAccess(RequestContextVO context) throws ODRException {
        UserType userType = context.getServiceActor().getUserType();
        final boolean isAuthorized = userType == UserType.Citizen && actorAndPatientIdsMatch(context)
                || userType == UserType.HealthCareProfessional
                || userType == UserType.Admin;

        if (!isAuthorized) {
            FaultUtil.throwODRFault(FaultCode.AUTHORIZATION_ERROR_PERSON_IDENTIFIER_ACCESS_DENIED);
        }
    }

    @Override
    public void checkHasAccess(RequestContextVO context) throws ODRException {
        UserType userType = context.getServiceActor().getUserType();
        final boolean isAuthorized = userType == UserType.Citizen && actorAndPatientIdsMatch(context)
                || userType == UserType.SystemUser
                || userType == UserType.HealthCareProfessional
                || userType == UserType.Admin;

        if (!isAuthorized) {
            FaultUtil.throwODRFault(FaultCode.AUTHORIZATION_ERROR_PERSON_IDENTIFIER_ACCESS_DENIED);
        }
    }

    @Override
    public void checkWriteAccess(RequestContextVO context) throws ODRException {
        UserType userType = context.getServiceActor().getUserType();
        final boolean isAuthorized = userType == UserType.Citizen && actorAndPatientIdsMatch(context)
                || userType == UserType.Admin;

        if (!isAuthorized) {
            FaultUtil.throwODRFault(FaultCode.AUTHORIZATION_ERROR_PERSON_IDENTIFIER_ACCESS_DENIED);
        }
    }

    private boolean actorAndPatientIdsMatch(RequestContextVO context) {
        String actorId = context.getServiceActor().getPersonIdentifier();
        return actorId != null && actorId.equals(context.getPersonIdentifier());
    }
}
