/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.service.conf;

import dk.sosi.seal.vault.ClasspathCredentialVault;
import dk.sosi.seal.vault.CredentialVault;
import dk.sundhedsdatastyrelsen.organdonor.service.integrations.minlog.MinLogClient;
import dk.sundhedsdatastyrelsen.organdonor.service.integrations.minlog.MinLogException;
import dk.sundhedsdatastyrelsen.organdonor.util.Properties;
import org.springframework.context.annotation.*;

@Configuration
@Profile("!development")
@ComponentScan(basePackages = "dk.sundhedsdatastyrelsen.organdonor")
public class OdrConfiguration {

    private static final String MINLOG_CONFIG_FILE_NAME = "/minlogclient.properties";

    @Bean
    public MinLogClient minLogClient() throws MinLogException {
        return new MinLogClient(MINLOG_CONFIG_FILE_NAME);
    }

    @Bean
    public CredentialVaultFactory credentialVaultFactory() {
        return new CredentialVaultFactory() {
            @Override
            public CredentialVault getCredentilVaultFromProperties(Properties properties, java.util.Properties sosiProperties) {
                String keyStoreFile = properties.getStsKeystore();
                String keyStorePassword = properties.getStsKeystorePassword();
                return  new ClasspathCredentialVault(sosiProperties, keyStoreFile, keyStorePassword);
            }
        };
    }
}
