/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.service.conf;

import dk.sundhedsdatastyrelsen.organdonor.service.auditlog.AuditLogger;
import dk.sundhedsdatastyrelsen.organdonor.service.util.HttpClientFactory;
import dk.sundhedsdatastyrelsen.organdonor.service.webservice.validation.CprExists;
import dk.sundhedsdatastyrelsen.organdonor.service.webservice.validation.CprExistsImpl;
import dk.sundhedsdatastyrelsen.organdonor.service.webservice.validation.CprExistsServiceClientFactory;
import dk.sundhedsdatastyrelsen.organdonor.util.Properties;
import org.apache.http.HttpStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class WebServiceConfig {

    @Autowired
    private Properties properties;

    @Bean
    public HttpClientFactory getHttpClientFactory() {
        return new HttpClientFactory(properties.getMaxTotalConnections(),
                properties.getDefaultMaxConnectionsPerRoute());
    }

    @Bean
    public CprExistsServiceClientFactory cprExistsServiceClientFactory(@Autowired HttpClientFactory httpClientFactory) {
        if (properties.getCprExistsUrl() == null) {
            throw new IllegalArgumentException("cprexists.url skal være sat, da denne skal bruges til " +
                    "påkrævet validering af alder.");
        }
        return new CprExistsServiceClientFactory(properties.getCprExistsUrl(), httpClientFactory,
                        (CprExists.ValidationLevel.REJECT.getValidationLevel()
                                .equals(properties.getCprExistsValidationLevel()) ?
                                HttpStatus.SC_INTERNAL_SERVER_ERROR : HttpStatus.SC_NON_AUTHORITATIVE_INFORMATION),
                        properties.getInactiveStatusList());
    }

    @Bean
    public CprExists.ValidationLevel getValidationLevel() {
        CprExists.ValidationLevel cprExists =
                CprExists.ValidationLevel.valueOf(properties.getCprExistsValidationLevel());
        if (cprExists == null) {
            throw new IllegalArgumentException(
                    "Værdien af cprexists.validationlevel skal være OFF, REJECT eller WARNING");
        }
        return cprExists;
    }

    @Bean
    public CprExists cprExists(@Autowired(required = false) CprExistsServiceClientFactory cprExistsServiceClientFactory,
                               @Autowired CprExists.ValidationLevel validationLevel,
                               @Autowired AuditLogger auditLogger) {
        return new CprExistsImpl(validationLevel, cprExistsServiceClientFactory, auditLogger,
                properties.getCprExistsMinAge());
    }

    @Bean
    public AuditLogger auditLogger() {
        return new AuditLogger();
    }

}
