/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.service.util;

public enum FaultCode {
    GENERAL_ERROR(100, "Der opstod en fejl", false),

    CREATE_ORGANDONORREGISTRATION_VALIDATION_ERROR(100, "Fejl i request ifm. registrering af en Organdonor", true),
    CREATE_ORGANDONORREGISTRATION_INTERNAL_SERVER_ERROR(101, "Intern fejl ifm. registrering af en Organdonor", false),

    UPDATE_ORGANDONORREGISTRATION_VALIDATION_ERROR(150, "Fejl i request ifm. updatering af en Organdonorregistrering", true),
    UPDATE_ORGANDONORREGISTRATION_INTERNAL_SERVER_ERROR(151, "Intern fejl ifm. updatering af en Organdonorregistrering", false),

    GET_ORGANDONORREGISTRATION_VALIDATION_ERROR(200, "Fejl i request ifm. opslag af en Organdonorregistrering", true),
    GET_ORGANDONORREGISTRATION_INTERNAL_SERVER_ERROR(201, "Intern fejl ifm. opslag af en Organdonorregistrering", false),

    DELETE_ORGANDONORREGISTRATION_VALIDATION_ERROR(300, "Fejl i request ifm. sletning af en Organdonorregistrering", true),
    DELETE_ORGANDONORREGISTRATION_INTERNAL_SERVER_ERROR(301, "Intern fejl ifm. sletning af en Organdonorregistrering", false),

    HAS_ORGANDONORREGISTRATION_VALIDATION_ERROR(350, "Fejl i request ifm. hent status for en Organdonorregistrering", true),
    HAS_ORGANDONORREGISTRATION_INTERNAL_SERVER_ERROR(351, "Intern fejl ifm. hent status for en Organdonorregistrering", false),

    AUTHORIZATION_ERROR_INVALID_SECURITY_TICKET(500, "Ugyldig sikkerhedsbillet", true),
    AUTHORIZATION_ERROR_PERSON_IDENTIFIER_ACCESS_DENIED(501, "Adgang til CPR-nummeret ikke tilladt", true),

    AUTHORIZATION_ERROR_INGEN_DELEGERING(502, "Delegering ikke tilladt", true),
    AUTHORIZATION_ERROR_INGEN_CVR(503, "CVR nummer ikke fundet i sikkerhedsbilletten", true),
    AUTHORIZATION_ERROR_USER_NOT_CPR(504, "Bruger skal være identificeret ved CPR nummer", true),
    AUTHORIZATION_ERROR_USERTYPE_NOT_SPECIFIED(505, "Brugertype kunne ikke bestemmes udfra sikkerhedsbillet", true),
    AUTHORIZATION_ERROR_USERTYPE_ADMIN_NOT_ALLOWED(506, "Sikkerhedsbillet giver ikke adgang til admin rollen", true),
    AUTHORIZATION_ERROR_WRONG_AUDIENCE(507, "Forkert audience i sikkerhedsbillet", true),
    AUTHORIZATION_ERROR_CVR_NOT_WHITELISTED(508, "CVR nummer ikke whitelisted til kald for systembrugere", true);

    private int code;
    private String message;
    private boolean warningOnly;

    public int getCode() {
        return code;
    }

    public String getMessage() {
        return message;
    }

    public boolean isWarningOnly() {
        return warningOnly;
    }

    FaultCode(int code, String message, boolean warningOnly) {
        this.code = code;
        this.message = message;
        this.warningOnly = warningOnly;
    }

    @Override
    public String toString() {
        return code + ": " + message;
    }
}
