/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.service.webservice.validation;

import dk.sundhedsdatastyrelsen.organdonor.service.webservice.exceptions.ValidationException;

public interface CprExists {

	// Used for test, because Spring does not have a mechanism for autowiring mocked instances
	void setServiceClient(CprExistsServiceClient sc);

	public enum ValidationLevel {

		OFF("OFF"), REJECT("REJECT"), WARNING("WARNING");

		public final String validationLevel;
		ValidationLevel(String validationLevel) {
			this.validationLevel = validationLevel;
		}
		
		public String getValidationLevel() {
			return validationLevel;
		}
		
		public static ValidationLevel valueOfValidationLevel(String level) {
			if (OFF.getValidationLevel().equalsIgnoreCase(level)) {
				return OFF;
			}
			if (REJECT.getValidationLevel().equalsIgnoreCase(level)) {
				return REJECT;
			}
			if (WARNING.getValidationLevel().equalsIgnoreCase(level)) {
				return WARNING;
			}
			return null;
		}
	}

	boolean validateCpr(String patientId) throws ValidationException;

	void validateAge(String patientId) throws ValidationException;
}
