/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.service.conf;

import dk.sdsd.nsp.slalog.api.SLALogItem;
import dk.sdsd.nsp.slalog.ws.SLALoggingServletFilter;
import dk.sundhedsdatastyrelsen.organdonor.service.AdminServlet;
import dk.sundhedsdatastyrelsen.organdonor.service.integrations.minlog.MinLogDataWrapper;
import dk.sundhedsdatastyrelsen.organdonor.service.webservice.OdrContextListener;
import dk.sundhedsdatastyrelsen.organdonor.service.webservice.OrganDonorWebService;
import dk.sundhedsdatastyrelsen.organdonor.service.webservice.context.SecurityContextProvider;
import dk.sundhedsdatastyrelsen.organdonor.service.webservice.validation.CprExists;
import dk.sundhedsdatastyrelsen.organdonor.service.webservice.validation.CprExistsServiceClient;
import dk.sundhedsdatastyrelsen.organdonor.service.webservice.validation.CprExistsServiceClientFactory;
import org.mockito.Mockito;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Profile;
import org.springframework.context.support.GenericApplicationContext;

import javax.servlet.ServletContext;
import javax.servlet.ServletRequest;
import javax.xml.ws.WebServiceContext;
import javax.xml.ws.handler.MessageContext;

@Configuration
@Profile("development")
public class TestWebServiceConfig {

    @Bean(name = "organDonorWebService")
    public OrganDonorWebService organDonorWebService(GenericApplicationContext springContext, @Autowired CprExists cprExists) {
        cprExists.setServiceClient(createFakeServiceClient());
        OrganDonorWebService organDonorWebService = new OrganDonorWebService();
        organDonorWebService.setContext(createWebServiceContext(springContext, false));
        return organDonorWebService;
    }

    @Bean(name = "organDonorAdminWebService")
    public OrganDonorWebService organDonorAdminWebService(GenericApplicationContext springContext, @Autowired CprExists cprExists) {
        cprExists.setServiceClient(createFakeServiceClient());
        OrganDonorWebService organDonorWebService = new OrganDonorWebService();
        organDonorWebService.setContext(createWebServiceContext(springContext, true));
        return organDonorWebService;
    }

    private CprExistsServiceClient createFakeServiceClient() {
        int age = 15;
        CprExistsServiceClient cprExistsServiceClient = Mockito.mock(CprExistsServiceClient.class);
        Mockito.when(cprExistsServiceClient.getAge(Mockito.anyString())).thenReturn(age + 1);

        CprExistsServiceClientFactory cprExistsServiceClientFactory = Mockito.mock(CprExistsServiceClientFactory.class);
        Mockito.when(cprExistsServiceClientFactory.createClient()).thenReturn(cprExistsServiceClient);
        return cprExistsServiceClientFactory.createClient();
    }


    @Bean
    public SecurityContextProvider securityContextProvider() {
        return Mockito.mock(SecurityContextProvider.class);
    }

    @Bean
    public MinLogDataWrapper minLogDataWrapper() {
        return Mockito.mock(MinLogDataWrapper.class);
    }

    private WebServiceContext createWebServiceContext(GenericApplicationContext springContext, boolean isAdmin) {
        SLALogItem slaLogItem = Mockito.mock(SLALogItem.class);

        ServletContext servletContext = Mockito.mock(ServletContext.class);
        Mockito.when(servletContext.getAttribute(Mockito.eq(OdrContextListener.ANNOTATION_CONFIG_CONTEXT)))
                .thenReturn(springContext);
        ServletRequest servletRequest = Mockito.mock(ServletRequest.class);
        Mockito.when(servletRequest.getAttribute(Mockito.eq(SLALoggingServletFilter.CURRENT_LOGITEM_REQUEST_KEY)))
                .thenReturn(slaLogItem);
        Mockito.when(servletRequest.getAttribute(Mockito.eq(AdminServlet.ADMIN_KEY))).thenReturn(isAdmin);

        MessageContext messageContext = Mockito.mock(MessageContext.class);
        Mockito.when(messageContext.get(Mockito.eq(MessageContext.SERVLET_CONTEXT))).thenReturn(servletContext);
        Mockito.when(messageContext.get(Mockito.eq(MessageContext.SERVLET_REQUEST))).thenReturn(servletRequest);

        WebServiceContext webServiceContext = Mockito.mock(WebServiceContext.class);
        Mockito.when(webServiceContext.getMessageContext()).thenReturn(messageContext);
        return webServiceContext;
    }
}
