/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.service.integrations.nas.organdonor;

import dk.sundhedsdatastyrelsen.organdonor._2022._08._01.OrgandonorUpdated;
import org.junit.Test;

import java.time.Instant;

import static org.junit.Assert.assertEquals;

public class NotificationBuilderTest {
    private final NotificationBuilder subject = new NotificationBuilder();

    @Test
    public void buildNotification_populatesDate() {
        // Arrange
        Instant pointInTime = Instant.parse("2021-02-12T10:15:30.00Z");

        // Act
        OrgandonorUpdated notification = subject.buildNotification(pointInTime);

        // Assert
        assertEquals("2021-02-12", notification.getDate());
    }

    @Test
    public void buildNotification_populatesType() {
        // Arrange
        Instant pointInTime = Instant.parse("2021-02-12T10:15:30.00Z");

        // Act
        OrgandonorUpdated notification = subject.buildNotification(pointInTime);

        // Assert
        assertEquals("http://sundhedsdatastyrelsen.dk/MessageDefinition/Organdonor-notification", notification.getType());
    }

    @Test
    public void buildNotification_populatesVersion() {
        // Arrange
        Instant pointInTime = Instant.parse("2021-02-12T10:15:30.00Z");

        // Act
        OrgandonorUpdated notification = subject.buildNotification(pointInTime);

        // Assert
        assertEquals("1", notification.getVersion());
    }
}