/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.service.integrations.nas.organdonor;

import dk.sundhedsdatastyrelsen.organdonor.service.integrations.nas.facade.NasFacade;
import dk.sundhedsdatastyrelsen.organdonor.service.integrations.nas.facade.dgws.DGWSFault;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.junit.MockitoJUnitRunner;

import java.time.Instant;

@RunWith(MockitoJUnitRunner.class)
public class NotificationSenderTest {
    @InjectMocks
    private NotificationSender subject;

    @Mock
    private NotificationBuilder notificationBuilder;

    @Mock
    private NasFacade nasFacade;

    @Test
    public void sendDataCardNotification_success() throws Exception {
        // Arrange
        String personIdentifier = "1212121212";
        Instant pointInTime = Instant.parse("2021-02-12T10:15:30.00Z");

        // Act
        subject.sendOrganDonorNotification(personIdentifier, pointInTime);

        // Assert
        Mockito.verify(notificationBuilder).buildNotification(pointInTime);
        Mockito.verify(nasFacade).notify(Mockito.any());
    }

    @Test(expected = NasException.class)
    public void sendDataCardNotification_exceptionIsWrapped() throws Exception {
        // Arrange
        String personIdentifier = "1212121212";
        Instant pointInTime = Instant.parse("2021-02-12T10:15:30.00Z");

        Mockito.doThrow(DGWSFault.class).when(nasFacade).notify(Mockito.any());

        // Act
        subject.sendOrganDonorNotification(personIdentifier, pointInTime);

        // Assert
    }
}