/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.organdonor.datacreator.util;

import dk.sundhedsdatastyrelsen.organdonor.domain.OrganDonorVO;
import dk.sundhedsdatastyrelsen.organdonor.domain.PermissionType;

import java.time.Instant;
import java.time.Year;
import java.time.ZoneOffset;

public class OrganDonorDataUtil {

    private static final Instant validTo = Year.of(8099).atDay(1).atStartOfDay(ZoneOffset.UTC).toInstant();

    public static OrganDonorVO getNewOrganDonor(String personIdentifier, Instant timeOfFirstData, Instant timeOfLastData) {
        final Instant currentTime = RandomDataUtil.getRandomInstantInInterval(timeOfFirstData, timeOfLastData);

        OrganDonorVO organDonor = new OrganDonorVO();

        // from param
        organDonor.setPersonIdentifier(personIdentifier);

        setRandomValues(organDonor);

        // fixed
        organDonor.setVersion(1);

        // random but same for both fields
        organDonor.setModifiedDateTime(currentTime);
        organDonor.setValidFrom(currentTime);

        // fixed
        organDonor.setValidTo(validTo);

        return organDonor;
    }

    public static OrganDonorVO getUpdatedOrganDonorData(OrganDonorVO currentOrganDonor) {
        final Instant oldModifiedDateTime = currentOrganDonor.getModifiedDateTime();
        final Instant newModifiedDateTime =
                RandomDataUtil.getRandomInstantInInterval(oldModifiedDateTime, oldModifiedDateTime.plusSeconds(3600));

        final OrganDonorVO organDonor = new OrganDonorVO();

        // keep
        organDonor.setPersonIdentifier(currentOrganDonor.getPersonIdentifier());

        setRandomValues(organDonor);

        // bump
        organDonor.setVersion(currentOrganDonor.getVersion() + 1);

        // random but same for both fields
        organDonor.setModifiedDateTime(newModifiedDateTime);
        organDonor.setValidFrom(newModifiedDateTime);

        // fixed
        organDonor.setValidTo(validTo);

        return organDonor;
    }

    private static void setRandomValues(OrganDonorVO organDonor) {
        final PermissionType randomPermissionType = getRandomPermissionType();
        organDonor.setPermissionType(randomPermissionType);

        if (randomPermissionType == PermissionType.LIMITED
                || randomPermissionType == PermissionType.LIMITED_WITH_RESEARCH) {
            organDonor.setHeart(RandomDataUtil.getRandomBoolean());
            organDonor.setKidneys(RandomDataUtil.getRandomBoolean());
            organDonor.setLungs(RandomDataUtil.getRandomBoolean());
            organDonor.setCorneas(RandomDataUtil.getRandomBoolean());
            organDonor.setLiver(RandomDataUtil.getRandomBoolean());
            organDonor.setSmallIntestine(RandomDataUtil.getRandomBoolean());
            organDonor.setPancreas(RandomDataUtil.getRandomBoolean());
            organDonor.setSkin(RandomDataUtil.getRandomBoolean());
        }

        if (randomPermissionType == PermissionType.FULL
                || randomPermissionType == PermissionType.FULL_WITH_RESEARCH
                || randomPermissionType == PermissionType.LIMITED
                || randomPermissionType == PermissionType.LIMITED_WITH_RESEARCH) {
            organDonor.setRelativeAcceptanceRequired(RandomDataUtil.getRandomBoolean());
        }
    }

    private static PermissionType getRandomPermissionType() {
        final PermissionType[] values = PermissionType.values();
        final int maxIndex = values.length - 1;
        final int randomNumber = RandomDataUtil.getRandomNumber(0, maxIndex);

        return values[randomNumber];
    }
}
